@@ -1,5 +1,6 @@
 import logging
 
+import dbus
 import telepathy
 
 try:
@@ -107,7 +108,6 @@ class RefreshVoicemail(object):
 
 		self._isStarted = False
 
-	@misc_utils.log_exception(_moduleLogger)
 	def _on_new_channel(self, bus, serviceName, connObjectPath, channelObjectPath, channelType):
 		if channelType != telepathy.interfaces.CHANNEL_TYPE_STREAMED_MEDIA:
 			return
@@ -118,7 +118,11 @@ class RefreshVoicemail(object):
 			return
 
 		conn = telepathy.client.Connection(serviceName, connObjectPath)
-		chan = telepathy.client.Channel(serviceName, channelObjectPath)
+		try:
+			chan = telepathy.client.Channel(serviceName, channelObjectPath)
+		except dbus.exceptions.UnknownMethodException:
+			_moduleLogger.exception("Client might not have implemented a deprecated method")
+			return
 		missDetection = telepathy_utils.WasMissedCall(
 			bus, conn, chan, self._on_missed_call, self._on_error_for_missed
 		)
@@ -136,6 +140,23 @@ class RefreshVoicemail(object):
 		self._outstandingRequests.remove(missDetection)
 
 
+class TimedDisconnect(object):
+
+	def __init__(self, connRef):
+		self._connRef = connRef
+		self.__delayedDisconnect = gobject_utils.Timeout(self._on_delayed_disconnect)
+
+	def start(self):
+		self.__delayedDisconnect.start(seconds=5)
+
+	def stop(self):
+		self.__delayedDisconnect.cancel()
+
+	def _on_delayed_disconnect(self):
+		_moduleLogger.info("Timed disconnect occurred")
+		self._connRef().disconnect(telepathy.CONNECTION_STATUS_REASON_NETWORK_ERROR)
+
+
 class AutoDisconnect(object):
 
 	def __init__(self, connRef):
